==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class NodeConfigSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConfigSourceFluent<A>{
  public NodeConfigSourceFluentImpl() {
  }
  public NodeConfigSourceFluentImpl(io.fabric8.kubernetes.api.model.NodeConfigSource instance) {
    this.withConfigMap(instance.getConfigMap()); 
  }
  private io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder configMap;
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource getConfigMap() {
    return this.configMap!=null?this.configMap.build():null;
  }
  public io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource buildConfigMap() {
    return this.configMap!=null?this.configMap.build():null;
  }
  public A withConfigMap(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource configMap) {
    _visitables.get("configMap").remove(this.configMap);
    if (configMap!=null){ this.configMap= new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(configMap); _visitables.get("configMap").add(this.configMap);} return (A) this;
  }
  public java.lang.Boolean hasConfigMap() {
    return this.configMap != null;
  }
  public A withNewConfigMap(java.lang.String kubeletConfigKey,java.lang.String name,java.lang.String namespace,java.lang.String resourceVersion,java.lang.String uid) {
    return (A)withConfigMap(new ConfigMapNodeConfigSource(kubeletConfigKey, name, namespace, resourceVersion, uid));
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> withNewConfigMap() {
    return new io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl.ConfigMapNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> withNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl.ConfigMapNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editConfigMap() {
    return withNewConfigMapLike(getConfigMap());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editOrNewConfigMap() {
    return withNewConfigMapLike(getConfigMap() != null ? getConfigMap(): new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editOrNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
    return withNewConfigMapLike(getConfigMap() != null ? getConfigMap(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConfigSourceFluentImpl that = (NodeConfigSourceFluentImpl) o;
    if (configMap != null ? !configMap.equals(that.configMap) :that.configMap != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configMap,  super.hashCode());
  }
  public class ConfigMapNestedImpl<N> extends io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConfigMapNestedImpl(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(this, item);
    }
    ConfigMapNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigSourceFluentImpl.this.withConfigMap(builder.build());
    }
    public N endConfigMap() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NodeConfigSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConfigSourceFluent<A>{
  public NodeConfigSourceFluentImpl() {
  }
  public NodeConfigSourceFluentImpl(io.fabric8.kubernetes.api.model.NodeConfigSource instance) {
    this.withConfigMap(instance.getConfigMap()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder configMap;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource getConfigMap() {
    return this.configMap!=null?this.configMap.build():null;
  }
  public io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource buildConfigMap() {
    return this.configMap!=null?this.configMap.build():null;
  }
  public A withConfigMap(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource configMap) {
    _visitables.get("configMap").remove(this.configMap);
    if (configMap!=null){ this.configMap= new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(configMap); _visitables.get("configMap").add(this.configMap);} return (A) this;
  }
  public java.lang.Boolean hasConfigMap() {
    return this.configMap != null;
  }
  public A withNewConfigMap(java.lang.String kubeletConfigKey,java.lang.String name,java.lang.String namespace,java.lang.String resourceVersion,java.lang.String uid) {
    return (A)withConfigMap(new ConfigMapNodeConfigSource(kubeletConfigKey, name, namespace, resourceVersion, uid));
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> withNewConfigMap() {
    return new io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl.ConfigMapNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> withNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl.ConfigMapNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editConfigMap() {
    return withNewConfigMapLike(getConfigMap());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editOrNewConfigMap() {
    return withNewConfigMapLike(getConfigMap() != null ? getConfigMap(): new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<A> editOrNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
    return withNewConfigMapLike(getConfigMap() != null ? getConfigMap(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConfigSourceFluentImpl that = (NodeConfigSourceFluentImpl) o;
    if (configMap != null ? !configMap.equals(that.configMap) :that.configMap != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configMap,  additionalProperties,  super.hashCode());
  }
  public class ConfigMapNestedImpl<N> extends io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigSourceFluent.ConfigMapNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConfigMapNestedImpl(io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(this, item);
    }
    ConfigMapNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ConfigMapNodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigSourceFluentImpl.this.withConfigMap(builder.build());
    }
    public N endConfigMap() {
      return and();
    }
    
  }
  
}
